@@ -1,4 +1,4 @@
-##- Nanar <nanardon@mandrake.org>
+##- Nanar <nanardon@zarb.org>
 ##-
 ##- This program is free software; you can redistribute it and/or modify
 ##- it under the terms of the GNU General Public License as published by
@@ -14,10 +14,13 @@
 ##- along with this program; if not, write to the Free Software
 ##- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 #
-# $Id: Files.pm 69 2005-12-19 00:22:37Z nanardon $
+# $Id: Files.pm 86 2005-12-22 20:01:59Z nanardon $
 
 package RPM4::Header::Files;
 
+use strict;
+use warnings;
+
 sub dircount {
     $_[0]->countdir();
 }
